//---------------------------------------------------------------------------
//
//  Common.nut
//
//---------------------------------------------------------------------------

// Aliases
vec2 <- Vector2;

// Colors
Colors <-
{
	White 		= Color( 255, 255, 255, 255 ),
	Black 		= Color( 0, 0, 0, 0 ),
	Gray		= Color( 128, 128, 128, 255 ),
	Red 		= Color( 255, 0, 0, 255 ),
	Green 		= Color( 0, 255, 0, 255 ),
	Blue 		= Color( 0, 0, 255, 255 ),
	Yellow		= Color( 255, 255, 0, 255 ),
	Purple		= Color( 255, 0, 255, 255 ),
	Teal		= Color( 0, 255, 255, 255 ),
	SpaceBlue 	= Color( 160, 190, 210, 255 ),
	LightBlue	= Color( 190, 220, 240, 255 ),
	LightGold	= Color( 255, 255, 120, 255 )
}

State <-
{
	function Begin() {}
	function End() {}
	function Execute() {}
}

class StateObject
{
	function GoToState( s )
	{
		local newState;
		
		if ( type(s) == "string" )
			newState = states[s];
		else if ( s != null )
			newState = s;
		else
			return;
	
		if ( state )
			state.End.call( this );
		
		oldState = state;
		state = newState;
		state.Begin.call( this );
		threadfunc( this, state.Execute );
	}
	
	function IsInState( name )
	{
		return state == states[name];
	}
	
	state = null;
	oldState = null;
	states = {};
}

function rf( x )
{
	print( refcount(x) );
}

function LoadSound( path, ... )
{
	try
	{
		if ( path == null )
			return null
		else if ( vargc==0 )
			return Sound( path )
		else if ( vargc==1 )
			return Sound( path, vargv[0] )
		else if ( vargc==2 )
			return Sound( path, vargv[0], vargv[1] )
	}
	catch ( e )
	{
		Warning( "Could not load sound: " + path )
		return null
	}
}

function min( a, b )
{
	if ( a < b )
		return a;
	else
		return b;
}

function max( a, b )
{
	if ( a > b )
		return a;
	else
		return b;
}

function clamp( x, low, high )
{
	if ( x < low )
		return low;
	else if ( x > high )
		return high;
	else
		return x;
}

function Sound( name, max )
{
	local sound =
	{
		path = name,
		playbacks = max
	};
	
	return sound;
}

